@@ -163,4 +163,32 @@ class DNSInventoryDO(BaseModel):
 
 class RecoverSettingDO(BaseModel):
     node_inventory: Optional[List[NodeInventoryDO]]
-    dns_inventory: Optional[List[DNSInventoryDO]]
\ No newline at end of file
+    dns_inventory: Optional[List[DNSInventoryDO]]
+
+
+
+class SearchRequestDO(BaseModel):
+    keyword: str
+    limit: int = 5
+    request_id: Optional[str] = None
+    others: Optional[dict] = None
+
+
+
+class SearchResponseDO(BaseModel):
+    status: str
+    exception: Optional[str] = None
+    result: Optional[dict] = None
+    others: Optional[dict] = None
+
+
+
+class SearchItemDO(BaseModel):
+    item_id: str
+    status: str
+    exception: Optional[str] = None
+    request: Optional[SearchRequestDO] = None
+    response: Optional[SearchResponseDO] = None
+    entry_time: Optional[datetime.datetime] = None
+    exit_time: Optional[datetime.datetime] = None
+    create_time: Optional[datetime.datetime] = None
\ No newline at end of file
